import { BaseTask, ESLintAnalyzer, } from '@checkup/core';
/**
 * @export
 * @description In prioritized order as specified by https://eslint.org/docs/user-guide/configuring
 */
export const ACCEPTED_ESLINT_CONFIG_FILES = [
    '.eslintrc.js',
    '.eslintrc.cjs',
    '.eslintrc.yaml',
    '.eslintrc.yml',
    '.eslintrc.json',
    '.eslintrc',
];
export default class EslintSummaryTask extends BaseTask {
    constructor(pluginName, context) {
        super(pluginName, context);
        this.taskName = 'eslint-summary';
        this.taskDisplayName = 'Eslint Summary';
        this.description = 'Gets a summary of all eslint results in a project';
        this.category = 'linting';
        this.addRule({
            properties: {
                component: {
                    name: 'list',
                    options: {
                        items: {
                            Errors: {
                                groupBy: 'level',
                                value: 'error',
                            },
                            Warnings: {
                                groupBy: 'level',
                                value: 'warning',
                            },
                        },
                    },
                },
            },
        });
        this.analyzer = new ESLintAnalyzer({
            cwd: this.context.options.cwd,
            useEslintrc: true,
        });
    }
    async run() {
        let lintResults = await this.analyzer.analyze(this.context.paths.filterByGlob('**/*.js'));
        let results = this.flattenLintResults(lintResults);
        results.forEach((result) => {
            this.addResult(result.message, 'review', result.severity === 2 ? 'error' : 'warning', {
                location: {
                    uri: result.filePath,
                    startColumn: result.column,
                    startLine: result.line,
                    endColumn: result.endColumn,
                    endLine: result.endLine,
                },
                properties: {
                    ruleId: result.lintRuleId,
                },
            });
        });
        return this.results;
    }
}
//# sourceMappingURL=eslint-summary-task.js.map